package sk.telepovsky.android.tutorials;

import sk.telepovsky.android.tutorials.R;
import sk.telepovsky.android.tutorials.components.ExpanderComponent;
import sk.telepovsky.android.tutorials.components.DialogCustom;
import sk.telepovsky.android.tutorials.components.Menu;
import sk.telepovsky.android.tutorials.components.Menu.MenuItemId;
import sk.telepovsky.android.tutorials.components.Menu.OnMenuItemSelectedListener;
import sk.telepovsky.android.tutorials.components.MenuItem;
import android.app.Activity;
import android.content.Context;
import android.content.DialogInterface;
import android.content.res.Configuration;
import android.graphics.Typeface;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends Activity implements OnClickListener, DialogInterface.OnClickListener, OnMenuItemSelectedListener {
    private Menu menu;
    private ExpanderComponent expander;
    
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
	super.onCreate(savedInstanceState);
	setContentView(R.layout.main);

	TextView tv_title = (TextView) findViewById(R.id.tv_title);
	Typeface font = Typeface.createFromAsset(getAssets(), "Continuum.ttf");
	tv_title.setTypeface(font);

	showDialog(this, getString(R.string.dialog_title), getString(R.string.dialog_message_like), getString(R.string.sure), getString(R.string.yes), this, R.drawable.np_dialog);

	findViewById(R.id.btn_press_me).setOnClickListener(this);

	// initialize the menu
	menu = new Menu(this, this);
	menu.setHideOnSelect(true);

	// load the menu items
	loadMenuItems();
	
	// ExpanderComponent
	expander = new ExpanderComponent(this, findViewById(R.id.toggler), findViewById(R.id.container), false);
    }

    private void showDialog(Context context, String title, String message, String positiveButton, String negativeButton, DialogInterface.OnClickListener listener, int backgroundResource) {

	DialogCustom.Builder customBuilder = new DialogCustom.Builder(context);

	customBuilder.setTitle(title).setMessage(message).setBackgroundResource(backgroundResource);

	if (positiveButton != null)
	    customBuilder.setPositiveButton(positiveButton, listener);

	if (negativeButton != null)
	    customBuilder.setNegativeButton(negativeButton, listener);

	customBuilder.show();
    }

    @Override
    public void onClick(View view) {
	showDialog(this, getString(R.string.dialog_title), getString(R.string.dialog_message_back), null, null, this, R.drawable.np_dialog);
    }

    @Override
    public void onClick(DialogInterface dialog, int which) {
	dialog.dismiss();
    }

    public boolean onKeyDown(int keyCode, KeyEvent event) {
	if (keyCode == KeyEvent.KEYCODE_MENU) {

	    if (menu != null)
		menu.doMenu();
	    return true;

	} else if (keyCode == KeyEvent.KEYCODE_BACK) {

	    if (menu != null && menu.isShowing()) {
		menu.hide();
		return true;
	    }

	}
	return super.onKeyDown(keyCode, event);
    }

    /**
     * Load menu items.
     */
    private void loadMenuItems() {
	if (menu.isShowing())
	    return;

	menu.addMenuItem(new MenuItem(MenuItemId.ABOUT, getString(R.string.about), R.drawable.icon_menu));
	menu.addMenuItem(new MenuItem(MenuItemId.HELP, getString(R.string.help), R.drawable.icon_menu));
    }

    @Override
    public void MenuItemSelectedEvent(MenuItem selection) {
	Toast.makeText(this, selection.getId().toString(), Toast.LENGTH_SHORT).show();
    }
    
    @Override
    public void onConfigurationChanged(Configuration newConfig) {
	super.onConfigurationChanged(newConfig);

	if (menu != null)
	    menu.onConfigurationChanged();
    }
}