package sk.telepovsky.android.tutorials.components;

import sk.telepovsky.android.tutorials.R;
import android.content.Context;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.animation.Animation;
import android.view.animation.Animation.AnimationListener;
import android.view.animation.AnimationUtils;

public class ExpanderComponent implements OnClickListener {
    private Boolean isContainerVisible, isAnimated;
    private View toggler, container;
    private Animation animationShow, animationHide;
    private AnimationListener showListener, hideListener;

    public ExpanderComponent(Context context, View toggler, View container, Boolean isContainerVisible) {
	isAnimated = false;
	this.toggler = toggler;
	this.container = container;
	this.isContainerVisible = isContainerVisible;

	toggler.setOnClickListener(this);

	// initialize container visibility
	int containerVisibility = isContainerVisible ? View.VISIBLE : View.GONE;
	container.setVisibility(containerVisibility);

	animationShow = AnimationUtils.loadAnimation(context, R.anim.slide_in_top);
	animationHide = AnimationUtils.loadAnimation(context, R.anim.slide_out_top);

	setAnimationListeners();
    }

    public View getContainer() {
	return container;
    }

    public View getToggler() {
	return toggler;
    }

    public void showContainer() {
	container.setVisibility(View.VISIBLE);
	container.startAnimation(animationShow);
    }

    public void hideContainer() {
	container.startAnimation(animationHide);
    }

    public Boolean isContainerVisible() {
	return isContainerVisible;
    }

    public void toggler_onClick() {
	if (isAnimated)
	    return;

	if (isContainerVisible)
	    hideContainer();
	else
	    showContainer();
    }

    public void onClick(View v) {
	switch (v.getId()) {
	case R.id.toggler:
	    toggler_onClick();
	    break;
	}
    }

    private void setAnimationListeners() {

	hideListener = new AnimationListener() {
	    public void onAnimationStart(Animation anim) {
		isAnimated = true;
	    };

	    public void onAnimationRepeat(Animation anim) {
	    };

	    public void onAnimationEnd(Animation anim) {
		container.setVisibility(View.GONE);
		isContainerVisible = false;
		isAnimated = false;
	    };
	};

	showListener = new AnimationListener() {
	    public void onAnimationStart(Animation anim) {
		isAnimated = true;
	    };

	    public void onAnimationRepeat(Animation anim) {
	    };

	    public void onAnimationEnd(Animation anim) {
		isContainerVisible = true;
		isAnimated = false;
	    };
	};

	animationShow.setAnimationListener(showListener);
	animationHide.setAnimationListener(hideListener);
    }
}